pub struct ActorContext<T = f32> { /* private fields */ }Expand description
The context for node operators; the context provides information about the current state of the operator and its environment.
Implementations
Sourceimpl<T> ActorContext<T>
impl<T> ActorContext<T>
Sourcepub fn new() -> ActorContext<T>where
T: Zero,
pub fn new() -> ActorContext<T>where
T: Zero,
Create a new context with default values
Sourcepub const fn harmonic_function(&self) -> Option<HarmonicFunction>
pub const fn harmonic_function(&self) -> Option<HarmonicFunction>
returns a copy of the harmonic function
Sourcepub const fn metric_position(&self) -> Option<MetricPosition>
pub const fn metric_position(&self) -> Option<MetricPosition>
returns a copy of the metric position
returns an immutable reference to the semantic tags
returns a mutable reference to the semantic tags
Sourcepub fn set_harmonic_function(&mut self, function: Option<HarmonicFunction>)
pub fn set_harmonic_function(&mut self, function: Option<HarmonicFunction>)
Set the harmonic function
Sourcepub fn set_metric_position(&mut self, position: Option<MetricPosition>)
pub fn set_metric_position(&mut self, position: Option<MetricPosition>)
Set the metric position
Sourcepub fn push_semantic_tag(&mut self, tag: String)
pub fn push_semantic_tag(&mut self, tag: String)
Add a semantic tag
Sourcepub fn set_stability(&mut self, stability: T)
pub fn set_stability(&mut self, stability: T)
Set the stability rating
Sourcepub fn with_harmonic_function(
self,
function: HarmonicFunction,
) -> ActorContext<T>
pub fn with_harmonic_function( self, function: HarmonicFunction, ) -> ActorContext<T>
consumes the current instance to create another with the given harmonic function
Sourcepub fn with_metric_position(self, position: MetricPosition) -> ActorContext<T>
pub fn with_metric_position(self, position: MetricPosition) -> ActorContext<T>
consumes the current instance to create another with the given metric position
consumes the current instance to create another with the given semantic tags
Sourcepub fn with_stability(self, stability: T) -> ActorContext<T>
pub fn with_stability(self, stability: T) -> ActorContext<T>
consumes the current instance to create another with the given stability rating