Operator

Enum Operator 

pub enum Operator<T> {
    Agent(Agent<T>),
    Observer(Observer<T>),
}
Enumerates the varios operators for the nodes, reducing the number of generics needed.

Variants



Agent(Agent<T>)



Observer(Observer<T>)

Implementations

Source

impl<T> Operator<T>

pub const fn is_agent(&self) -> bool

Returns true if the enum is Operator::Agent otherwise false

pub const fn is_observer(&self) -> bool

Returns true if the enum is Operator::Observer otherwise false

Source

impl<T> Operator<T>

pub fn active_operator<D>(&self) -> &dyn Actor<D, T>

Get the current active operator as Actor trait object

pub fn active_operator_mut<D>(&mut self) -> &mut dyn Actor<D, T>

Get the current active operator as Actor trait object (mutable)