MemoryPosition

Struct MemoryPosition 

pub struct MemoryPosition<T = usize> { /* private fields */ }
MemoryPosition tracks the current indices for various aspects of the memory system to ensure consistency when allocating new features or patterns.

Implementations

Source

impl<T> MemoryPosition<T>

pub fn new(feature_id: T, pattern_id: T) -> MemoryPosition<T>

returns a new instance of MemoryPosition using the provided feature_id and pattern_id.

pub fn default() -> MemoryPosition<T>
where T: Default,

initializes a new instance using the logical Default for type T.

pub fn one() -> MemoryPosition<T>
where T: One,

initialize a new instance using num_traits::One

pub fn zero() -> MemoryPosition<T>
where T: Zero,

initialize a new instance using num_traits::Zero

pub fn from_feature_id(feature_id: T) -> MemoryPosition<T>
where T: Default,

creates a new instance of MemoryPosition from a given feature_id and a default pattern_id.

pub fn from_pattern_id(pattern_id: T) -> MemoryPosition<T>
where T: Default,

creates a new instance of MemoryPosition from a given pattern_id and a default feature_id.

pub const fn feature_id(&self) -> &T

returns an immutable reference to the current feature id

pub const fn feature_id_mut(&mut self) -> &mut T

returns a mutable reference to the current feature id

pub const fn pattern_id(&self) -> &T

returns an immutable reference to the current pattern id

pub const fn pattern_id_mut(&mut self) -> &mut T

returns a mutable reference to the current pattern id

pub const fn replace_feature_id(&mut self, id: T) -> T

replace the current feature ID with the given id and return the old value.

pub const fn replace_pattern_id(&mut self, id: T) -> T

replace the current pattern ID with the given id and return the old value.

pub fn next_feature_id(&mut self) -> T
where T: One, &'a T: for<'a> Add<T, Output = T>,

returns the current feature id, replacing it with the logical successor

pub fn next_pattern_id(&mut self) -> T
where T: One, &'a T: for<'a> Add<T, Output = T>,

returns the current pattern id and replaces it with an incremented value