NeuralEngine

Struct NeuralEngine 

pub struct NeuralEngine<T = f32> { /* private fields */ }
A Neural Turing Machine (NTM) is a type of recurrent neural network that can learn to perform algorithmic tasks by interacting with an external memory. The NTM consists of a controller network that interacts with a memory matrix using attention mechanisms. Internally, the controller is a shallow feed-forward neural network capable of processing encoded inputs and producing outputs that determine the next state, symbol, and direction of the machine.

Implementations

Source

impl<T> NeuralEngine<T>

pub const STATES: usize = 2usize

pub const SYMBOLS: usize = 3usize

pub fn new(alphabet: [usize; 3], _: State<usize>) -> NeuralEngine<T>

pub const fn alphabet(&self) -> &[usize; 3]

returns an immutable reference to the alphabet

pub const fn controller(&self) -> &NeuralController<T>

returns an immutable reference to the controller

pub fn controller_mut(&mut self) -> &mut NeuralController<T>

returns a mutable reference to the controller

pub const fn features(&self) -> NeuralFeatures

returns a copy of the engine controller’s features

pub fn features_mut(&mut self) -> &mut NeuralFeatures

returns a mutable reference to the engine controller’s features

pub const fn memory(&self) -> &ArrayBase<OwnedRepr<T>, Dim<[usize; 2]>>

returns an immutable reference to the memory of the machine

pub fn memory_mut(&mut self) -> &mut ArrayBase<OwnedRepr<T>, Dim<[usize; 2]>>

returns a mutable reference to the memory of the machine

pub const fn position(&self) -> usize

returns the current position of the head of the machine

pub fn position_mut(&mut self) -> &mut usize

returns a mutable reference to the position of the head of the machine

pub const fn state(&self) -> State<usize>

returns a copy of the state of the machine

pub fn state_mut(&mut self) -> &mut State<usize>

returns a mutable reference to the state of the machine

pub const fn tape(&self) -> &Vec<usize>

returns an immutable reference to the tape of the machine

pub fn tape_mut(&mut self) -> &mut Vec<usize>

returns a mutable reference to the tape of the machine

pub fn set_position(&mut self, position: usize)

set the current position of the machine

pub fn set_state(&mut self, state: State<usize>)

set the state of the machine

pub fn set_tape<I>(&mut self, iter: I)
where I: IntoIterator<Item = usize>,

set the tape of the machine

pub fn head(&self) -> Head<usize, usize>

returns the head of the machine

pub fn init(self) -> NeuralEngine<T>

inititalize the controller and return a new instance with the randomized parameters

pub fn reset(&mut self)

clear’s the contents of the tape and resets the position of the head back to 0

pub fn reset_position(&mut self)

reset the position of the head of the machine to 0

Source

impl<T> NeuralEngine<T>

pub fn adapt_to_target( &mut self, tail: Tail<usize, usize>, ) -> Result<(), ActorError>
where T: NumAssign + Sum,

adapt the engine’s weights to the target tail (pattern)

pub fn decode_outputs_into_tail( &self, output: ArrayBase<OwnedRepr<T>, Dim<[usize; 1]>>, ) -> Tail<usize, usize>

extract a tail (next_state, next_symbol, direction) from controller output

pub fn determine_best_direction(&self, expected: usize) -> Direction

determine the best direction toDetermine best direction to reach expected symbol based on current state and tape

pub fn encode_input_symbol( &self, symbol: usize, ) -> ArrayBase<OwnedRepr<T>, Dim<[usize; 1]>>

Prepares the input for the controller network by combining state and symbol information

pub fn execute_with_stored( &mut self, memory: &TopoLedger<T>, ) -> Result<(), ActorError>
where T: NumAssign + Sum,

Execute the NTM using learned rules from topological memory

pub fn forward( &self, input: &ArrayBase<OwnedRepr<T>, Dim<[usize; 1]>>, ) -> Result<ArrayBase<OwnedRepr<T>, Dim<[usize; 1]>>, Error>

forward input through the controller

pub fn learn_sequence<U, V>( &mut self, inputs: &ArrayBase<U, Dim<[usize; 1]>>, targets: &ArrayBase<V, Dim<[usize; 1]>>, ) -> Result<T, ActorError>
where U: Data<Elem = usize>, V: Data<Elem = usize>, T: NumAssign + Sum, NeuralEngine<T>: ComputationalEngine<usize, [usize; 3], Store = Vec<usize>>,

train the model to learn the given dataset for a number of epochs

pub fn learn_sequence_for<U, V>( &mut self, inputs: &ArrayBase<U, Dim<[usize; 1]>>, targets: &ArrayBase<V, Dim<[usize; 1]>>, epochs: usize, ) -> Result<T, ActorError>
where U: Data<Elem = usize>, V: Data<Elem = usize>, T: NumAssign + Sum,

train the model to learn the given dataset for a number of epochs

pub fn predict_sequence(&mut self, n: usize) -> Vec<usize>

Predict the next n symbols in the sequence

pub fn learn_sequences_for<U, V>( &mut self, inputs: &ArrayBase<U, Dim<[usize; 2]>>, targets: &ArrayBase<V, Dim<[usize; 2]>>, epochs: usize, ) -> Result<T, ActorError>
where U: Data<Elem = usize>, V: Data<Elem = usize>, T: NumAssign + Sum,

train the engine on a sequence of inputs with their expected targets

pub fn read_memory(&self) -> ArrayBase<OwnedRepr<T>, Dim<[usize; 1]>>
where ArrayBase<ViewRepr<&'a T>, Dim<[usize; 2]>>: for<'a> Dot<ArrayBase<OwnedRepr<T>, Dim<[usize; 1]>>, Output = ArrayBase<OwnedRepr<T>, Dim<[usize; 1]>>>,

read from memory using attention mechanism

pub fn step(&mut self) -> Result<(), ActorError>

Perform a single step of the Turing machine

pub fn update_attention( &mut self, inputs: ArrayBase<OwnedRepr<T>, Dim<[usize; 1]>>, )

update the attention mechanism using controller output

pub fn write_memory( &mut self, erase: &ArrayBase<OwnedRepr<T>, Dim<[usize; 1]>>, add: &ArrayBase<OwnedRepr<T>, Dim<[usize; 1]>>, )

write to memory using attention mechanism