NeuralFeatures

Struct NeuralFeatures 

pub struct NeuralFeatures { /* private fields */ }

Implementations

Source

impl NeuralFeatures

pub fn new( attention: usize, memory: usize, inputs: usize, outputs: usize, hidden: usize, layers: usize, ) -> NeuralFeatures

pub const fn attention(&self) -> usize

returns a copy of the attention size

pub const fn codex(&self) -> usize

returns a copy of the number of features within the read/write heads

pub const fn hidden(&self) -> usize

returns a copy of the hidden size

pub const fn inputs(&self) -> usize

returns a copy of the input size

pub const fn layers(&self) -> usize

returns a copy of the number of hidden layers

pub const fn outputs(&self) -> usize

returns a copy of the output size

pub const fn dim_attention(&self) -> (usize, usize)

the shape of the attention layer (n_outputs, n_attention)

pub const fn dim_input(&self) -> (usize, usize)

the shape of the input layer (inputs, n_hidden)

pub const fn dim_hidden(&self) -> (usize, usize)

the shape of the hidden layer (hidden, hidden)

pub const fn dim_memory(&self) -> (usize, usize)

the shape of the memory matrix (n_memory, n_attention)

pub const fn dim_output(&self) -> (usize, usize)

the shape of the output layer (n_hidden, n_out)

pub fn set_attention(&mut self, attention: usize)

set the number of features for attention

pub fn set_codex(&mut self, codex: usize)

set the number of features for the read/write heads

pub fn set_inputs(&mut self, inputs: usize)

set the number of features for then input layer

pub fn set_hidden(&mut self, hidden: usize)

set the number of features for the hidden layer

pub fn set_outputs(&mut self, outputs: usize)

set the number of features for the output layer

pub fn with_attention(self, attention: usize) -> NeuralFeatures

consumes the current instance; returns another with the given number of features for attention

pub fn with_codex(self, codex: usize) -> NeuralFeatures

consumes the current instance; returns another with the given number of features for the read/write heads

pub fn with_inputs(self, inputs: usize) -> NeuralFeatures

consumes the current instance; returns another with the given number of input features

pub fn with_hidden(self, hidden: usize) -> NeuralFeatures

consumes the current instance; returns another with the given number of hidden features

pub fn with_outputs(self, outputs: usize) -> NeuralFeatures

consumes the current instance; returns another with the given number of output features