Observer

Struct Observer 

pub struct Observer<T = f32> { /* private fields */ }
Observer actors monitor the system without directly intervening. They collect data, analyze patterns, and build context but do not initiate transformations.

Implementations

Source

impl<T> Observer<T>

pub fn new() -> Observer<T>
where T: FromPrimitive,

Create a new observer

pub const fn id(&self) -> Id

returns a copy of the observer’s ID

pub const fn is_initialized(&self) -> bool

returns true if the observer is initialized

pub const fn is_uninitialized(&self) -> bool

returns true if the observer is not initialized

pub const fn threshold(&self) -> &T

returns a reference to the observation threshold

pub const fn threshold_mut(&mut self) -> &mut T

returns a mutable reference to the observation threshold

pub const fn observations(&self) -> &VecDeque<(LPR, Triads, Triads)>

returns an immutable reference to the observations

pub const fn observations_mut(&mut self) -> &mut VecDeque<(LPR, Triads, Triads)>

returns a mutable reference to the observations

pub const fn tonal_regions(&self) -> &HashMap<[usize; 3], String>

returns an immutable reference to the tonal regions

pub const fn tonal_regions_mut(&mut self) -> &mut HashMap<[usize; 3], String>

returns a mutable reference to the tonal regions

pub fn set_id(&mut self, id: Id) -> &mut Observer<T>

update the current id and return a mutable reference to the observer

pub fn set_threshold(&mut self, threshold: T) -> &mut Observer<T>
where T: Float,

update the current threshold and return a mutable reference to the observer

pub fn set_observations( &mut self, observations: VecDeque<(LPR, Triads, Triads)>, ) -> &mut Observer<T>

update the current observations and return a mutable reference to the observer

pub fn set_tonal_regions( &mut self, tonal_regions: HashMap<[usize; 3], String>, ) -> &mut Observer<T>

update the current tonal regions and return a mutable reference to the observer

pub fn initialized(self) -> Observer<T>

consumes the current instance to toggle the initialized flag

pub fn with_id(self, id: Id) -> Observer<T>

consumes the current instance to create another with the given ID

pub fn with_observations( self, observations: VecDeque<(LPR, Triads, Triads)>, ) -> Observer<T>

consumes the current instance to create another with the given observations

pub fn with_threshold(self, threshold: T) -> Observer<T>
where T: Float,

consumes the current instance to create another with the given threshold

pub fn with_tonal_regions( self, tonal_regions: HashMap<[usize; 3], String>, ) -> Observer<T>

consumes the current instance to create another with the given tonal regions

pub fn initialize(self) -> Observer<T>

set the initialized flag to true

pub fn observation_count(&self) -> usize

Get the number of transformations observed

pub fn analyze_patterns(&self, memory: &TopoLedger<T>) -> Vec<(Vec<LPR>, T)>
where T: Float + FromPrimitive,

Analyze recent transformations for patterns

pub fn analyze_critical_points<D>(&self, vnode: &VNode<D>) -> Vec<(String, T)>

Analyze critical points in relation to triad