UnitSphere

Struct UnitSphere 

pub struct UnitSphere;
Samples uniformly from the surface of the unit sphere in three dimensions.

Implemented via a method by Marsaglia1.

For a distribution that also samples from the interior of the sphere, see UnitBall.

For a similar distribution in two dimensions, see UnitCircle.

Plot

The following plot shows the unit sphere as a wireframe. The wireframe is meant to illustrate that this distribution samples from the surface of the sphere only, not from the interior.

Unit sphere

Example

use rand_distr::{UnitSphere, Distribution};

let v: [f64; 3] = UnitSphere.sample(&mut rand::rng());
println!("{:?} is from the unit sphere surface.", v)

  1. Marsaglia, George (1972). Choosing a Point from the Surface of a Sphere. Ann. Math. Statist. 43, no. 2, 645–646.