pub struct PathFinderConfig { /* private fields */ }Expand description
The PathFinderConfig object provides a standard interface for configuring various
implemented transformers.
Implementations
Sourceimpl PathFinderConfig
impl PathFinderConfig
Sourcepub const DEFAULT_MAX_DEPTH: usize = 5usize
pub const DEFAULT_MAX_DEPTH: usize = 5usize
the default maximum search depth for pathfinding
Sourcepub const DEFAULT_MAX_PATHS: usize = 5usize
pub const DEFAULT_MAX_PATHS: usize = 5usize
the default maximum number of paths to find
Sourcepub fn new(depth: usize, paths: usize) -> PathFinderConfig
pub fn new(depth: usize, paths: usize) -> PathFinderConfig
returns a new instance of the PathFinderConfig with the given values
Sourcepub fn from_depth(depth: usize) -> PathFinderConfig
pub fn from_depth(depth: usize) -> PathFinderConfig
returns a new instance of the PathFinderConfig with the given depth and default
paths
Sourcepub fn from_paths(paths: usize) -> PathFinderConfig
pub fn from_paths(paths: usize) -> PathFinderConfig
returns a new instance of the PathFinderConfig with the given paths and default
depth
Sourcepub const fn max_depth_mut(&mut self) -> &mut usize
pub const fn max_depth_mut(&mut self) -> &mut usize
returns a mutable reference to the maximum depth for pathfinding
Sourcepub const fn max_paths_mut(&mut self) -> &mut usize
pub const fn max_paths_mut(&mut self) -> &mut usize
returns a mutable reference to the maximum number of paths to find
Sourcepub fn set_max_depth(&mut self, depth: usize) -> &mut PathFinderConfig
pub fn set_max_depth(&mut self, depth: usize) -> &mut PathFinderConfig
set the maximum depth for pathfinding
Sourcepub fn set_max_paths(&mut self, paths: usize) -> &mut PathFinderConfig
pub fn set_max_paths(&mut self, paths: usize) -> &mut PathFinderConfig
set the maximum number of paths to find
Sourcepub fn with_max_depth(self, depth: usize) -> PathFinderConfig
pub fn with_max_depth(self, depth: usize) -> PathFinderConfig
consumes the current instance to create another with the given maximum depth
Sourcepub fn with_max_paths(self, paths: usize) -> PathFinderConfig
pub fn with_max_paths(self, paths: usize) -> PathFinderConfig
consumes the current instance to create another with the given maximum number of paths