pub enum Operator<T> {
Agent(Agent<T>),
Observer(Observer<T>),
}Expand description
Enumerates the varios operators for the nodes, reducing the number of generics needed.
Variants
Implementations
Sourceimpl<T> Operator<T>
impl<T> Operator<T>
Sourcepub const fn is_agent(&self) -> bool
pub const fn is_agent(&self) -> bool
Returns true if the enum is Operator::Agent otherwise false
Sourcepub const fn is_observer(&self) -> bool
pub const fn is_observer(&self) -> bool
Returns true if the enum is Operator::Observer otherwise false
Sourceimpl<T> Operator<T>
impl<T> Operator<T>
Sourcepub fn active_operator<D>(&self) -> &dyn Actor<D, T>
pub fn active_operator<D>(&self) -> &dyn Actor<D, T>
Get the current active operator as Actor trait object
Sourcepub fn active_operator_mut<D>(&mut self) -> &mut dyn Actor<D, T>
pub fn active_operator_mut<D>(&mut self) -> &mut dyn Actor<D, T>
Get the current active operator as Actor trait object (mutable)