pub struct MemoryPosition<T = usize> { /* private fields */ }Expand description
MemoryPosition tracks the current indices for various aspects of the memory system to
ensure consistency when allocating new features or patterns.
Implementations
Sourceimpl<T> MemoryPosition<T>
impl<T> MemoryPosition<T>
Sourcepub fn new(feature_id: T, pattern_id: T) -> MemoryPosition<T>
pub fn new(feature_id: T, pattern_id: T) -> MemoryPosition<T>
returns a new instance of MemoryPosition using the provided feature_id and
pattern_id.
Sourcepub fn default() -> MemoryPosition<T>where
T: Default,
pub fn default() -> MemoryPosition<T>where
T: Default,
initializes a new instance using the logical Default for type T.
Sourcepub fn one() -> MemoryPosition<T>where
T: One,
pub fn one() -> MemoryPosition<T>where
T: One,
initialize a new instance using num_traits::One
Sourcepub fn zero() -> MemoryPosition<T>where
T: Zero,
pub fn zero() -> MemoryPosition<T>where
T: Zero,
initialize a new instance using num_traits::Zero
Sourcepub fn from_feature_id(feature_id: T) -> MemoryPosition<T>where
T: Default,
pub fn from_feature_id(feature_id: T) -> MemoryPosition<T>where
T: Default,
creates a new instance of MemoryPosition from a given feature_id and a default
pattern_id.
Sourcepub fn from_pattern_id(pattern_id: T) -> MemoryPosition<T>where
T: Default,
pub fn from_pattern_id(pattern_id: T) -> MemoryPosition<T>where
T: Default,
creates a new instance of MemoryPosition from a given pattern_id and a default
feature_id.
Sourcepub const fn feature_id(&self) -> &T
pub const fn feature_id(&self) -> &T
returns an immutable reference to the current feature id
Sourcepub const fn feature_id_mut(&mut self) -> &mut T
pub const fn feature_id_mut(&mut self) -> &mut T
returns a mutable reference to the current feature id
Sourcepub const fn pattern_id(&self) -> &T
pub const fn pattern_id(&self) -> &T
returns an immutable reference to the current pattern id
Sourcepub const fn pattern_id_mut(&mut self) -> &mut T
pub const fn pattern_id_mut(&mut self) -> &mut T
returns a mutable reference to the current pattern id
Sourcepub const fn replace_feature_id(&mut self, id: T) -> T
pub const fn replace_feature_id(&mut self, id: T) -> T
replace the current feature ID with the given id and return
the old value.
Sourcepub const fn replace_pattern_id(&mut self, id: T) -> T
pub const fn replace_pattern_id(&mut self, id: T) -> T
replace the current pattern ID with the given id and return
the old value.
Sourcepub fn next_feature_id(&mut self) -> T
pub fn next_feature_id(&mut self) -> T
returns the current feature id, replacing it with the logical successor
Sourcepub fn next_pattern_id(&mut self) -> T
pub fn next_pattern_id(&mut self) -> T
returns the current pattern id and replaces it with an incremented value