pub struct NeuralEngine<T = f32> { /* private fields */ }Expand description
A Neural Turing Machine (NTM) is a type of recurrent neural network that can learn to perform algorithmic tasks by interacting with an external memory. The NTM consists of a controller network that interacts with a memory matrix using attention mechanisms. Internally, the controller is a shallow feed-forward neural network capable of processing encoded inputs and producing outputs that determine the next state, symbol, and direction of the machine.
Implementations
Sourceimpl<T> NeuralEngine<T>
impl<T> NeuralEngine<T>
pub const STATES: usize = 2usize
pub const SYMBOLS: usize = 3usize
pub fn new(alphabet: [usize; 3], _: State<usize>) -> NeuralEngine<T>
Sourcepub const fn controller(&self) -> &NeuralController<T>
pub const fn controller(&self) -> &NeuralController<T>
returns an immutable reference to the controller
Sourcepub fn controller_mut(&mut self) -> &mut NeuralController<T>
pub fn controller_mut(&mut self) -> &mut NeuralController<T>
returns a mutable reference to the controller
Sourcepub const fn features(&self) -> NeuralFeatures
pub const fn features(&self) -> NeuralFeatures
returns a copy of the engine controller’s features
Sourcepub fn features_mut(&mut self) -> &mut NeuralFeatures
pub fn features_mut(&mut self) -> &mut NeuralFeatures
returns a mutable reference to the engine controller’s features
Sourcepub const fn memory(&self) -> &ArrayBase<OwnedRepr<T>, Dim<[usize; 2]>>
pub const fn memory(&self) -> &ArrayBase<OwnedRepr<T>, Dim<[usize; 2]>>
returns an immutable reference to the memory of the machine
Sourcepub fn memory_mut(&mut self) -> &mut ArrayBase<OwnedRepr<T>, Dim<[usize; 2]>>
pub fn memory_mut(&mut self) -> &mut ArrayBase<OwnedRepr<T>, Dim<[usize; 2]>>
returns a mutable reference to the memory of the machine
Sourcepub fn position_mut(&mut self) -> &mut usize
pub fn position_mut(&mut self) -> &mut usize
returns a mutable reference to the position of the head of the machine
Sourcepub fn state_mut(&mut self) -> &mut State<usize>
pub fn state_mut(&mut self) -> &mut State<usize>
returns a mutable reference to the state of the machine
Sourcepub const fn tape(&self) -> &Vec<usize>
pub const fn tape(&self) -> &Vec<usize>
returns an immutable reference to the tape of the machine
Sourcepub fn tape_mut(&mut self) -> &mut Vec<usize>
pub fn tape_mut(&mut self) -> &mut Vec<usize>
returns a mutable reference to the tape of the machine
Sourcepub fn set_position(&mut self, position: usize)
pub fn set_position(&mut self, position: usize)
set the current position of the machine
Sourcepub fn set_tape<I>(&mut self, iter: I)where
I: IntoIterator<Item = usize>,
pub fn set_tape<I>(&mut self, iter: I)where
I: IntoIterator<Item = usize>,
set the tape of the machine
Sourcepub fn init(self) -> NeuralEngine<T>
pub fn init(self) -> NeuralEngine<T>
inititalize the controller and return a new instance with the randomized parameters
Sourcepub fn reset(&mut self)
pub fn reset(&mut self)
clear’s the contents of the tape and resets the position of the head back to 0
Sourcepub fn reset_position(&mut self)
pub fn reset_position(&mut self)
reset the position of the head of the machine to 0
Sourceimpl<T> NeuralEngine<T>where
T: Float + FromPrimitive + ScalarOperand,
NeuralEngine<T>: ComputationalEngine<usize, [usize; 3], Store = Vec<usize>>,
impl<T> NeuralEngine<T>where
T: Float + FromPrimitive + ScalarOperand,
NeuralEngine<T>: ComputationalEngine<usize, [usize; 3], Store = Vec<usize>>,
Sourcepub fn adapt_to_target(
&mut self,
tail: Tail<usize, usize>,
) -> Result<(), ActorError>
pub fn adapt_to_target( &mut self, tail: Tail<usize, usize>, ) -> Result<(), ActorError>
adapt the engine’s weights to the target tail (pattern)
Sourcepub fn decode_outputs_into_tail(
&self,
output: ArrayBase<OwnedRepr<T>, Dim<[usize; 1]>>,
) -> Tail<usize, usize>
pub fn decode_outputs_into_tail( &self, output: ArrayBase<OwnedRepr<T>, Dim<[usize; 1]>>, ) -> Tail<usize, usize>
extract a tail (next_state, next_symbol, direction) from controller output
Sourcepub fn determine_best_direction(&self, expected: usize) -> Direction
pub fn determine_best_direction(&self, expected: usize) -> Direction
determine the best direction toDetermine best direction to reach expected symbol based on current state and tape
Sourcepub fn encode_input_symbol(
&self,
symbol: usize,
) -> ArrayBase<OwnedRepr<T>, Dim<[usize; 1]>>
pub fn encode_input_symbol( &self, symbol: usize, ) -> ArrayBase<OwnedRepr<T>, Dim<[usize; 1]>>
Prepares the input for the controller network by combining state and symbol information
Sourcepub fn execute_with_stored(
&mut self,
memory: &TopoLedger<T>,
) -> Result<(), ActorError>
pub fn execute_with_stored( &mut self, memory: &TopoLedger<T>, ) -> Result<(), ActorError>
Execute the NTM using learned rules from topological memory
Sourcepub fn forward(
&self,
input: &ArrayBase<OwnedRepr<T>, Dim<[usize; 1]>>,
) -> Result<ArrayBase<OwnedRepr<T>, Dim<[usize; 1]>>, Error>
pub fn forward( &self, input: &ArrayBase<OwnedRepr<T>, Dim<[usize; 1]>>, ) -> Result<ArrayBase<OwnedRepr<T>, Dim<[usize; 1]>>, Error>
forward input through the controller
Sourcepub fn learn_sequence<U, V>(
&mut self,
inputs: &ArrayBase<U, Dim<[usize; 1]>>,
targets: &ArrayBase<V, Dim<[usize; 1]>>,
) -> Result<T, ActorError>
pub fn learn_sequence<U, V>( &mut self, inputs: &ArrayBase<U, Dim<[usize; 1]>>, targets: &ArrayBase<V, Dim<[usize; 1]>>, ) -> Result<T, ActorError>
train the model to learn the given dataset for a number of epochs
Sourcepub fn learn_sequence_for<U, V>(
&mut self,
inputs: &ArrayBase<U, Dim<[usize; 1]>>,
targets: &ArrayBase<V, Dim<[usize; 1]>>,
epochs: usize,
) -> Result<T, ActorError>
pub fn learn_sequence_for<U, V>( &mut self, inputs: &ArrayBase<U, Dim<[usize; 1]>>, targets: &ArrayBase<V, Dim<[usize; 1]>>, epochs: usize, ) -> Result<T, ActorError>
train the model to learn the given dataset for a number of epochs
Sourcepub fn predict_sequence(&mut self, n: usize) -> Vec<usize>
pub fn predict_sequence(&mut self, n: usize) -> Vec<usize>
Predict the next n symbols in the sequence
Sourcepub fn learn_sequences_for<U, V>(
&mut self,
inputs: &ArrayBase<U, Dim<[usize; 2]>>,
targets: &ArrayBase<V, Dim<[usize; 2]>>,
epochs: usize,
) -> Result<T, ActorError>
pub fn learn_sequences_for<U, V>( &mut self, inputs: &ArrayBase<U, Dim<[usize; 2]>>, targets: &ArrayBase<V, Dim<[usize; 2]>>, epochs: usize, ) -> Result<T, ActorError>
train the engine on a sequence of inputs with their expected targets
Sourcepub fn read_memory(&self) -> ArrayBase<OwnedRepr<T>, Dim<[usize; 1]>>
pub fn read_memory(&self) -> ArrayBase<OwnedRepr<T>, Dim<[usize; 1]>>
read from memory using attention mechanism
Sourcepub fn step(&mut self) -> Result<(), ActorError>
pub fn step(&mut self) -> Result<(), ActorError>
Perform a single step of the Turing machine