pub struct NeuralFeatures { /* private fields */ }Implementations
Sourceimpl NeuralFeatures
impl NeuralFeatures
pub fn new( attention: usize, memory: usize, inputs: usize, outputs: usize, hidden: usize, layers: usize, ) -> NeuralFeatures
Sourcepub const fn codex(&self) -> usize
pub const fn codex(&self) -> usize
returns a copy of the number of features within the read/write heads
returns a copy of the hidden size
Sourcepub const fn dim_attention(&self) -> (usize, usize)
pub const fn dim_attention(&self) -> (usize, usize)
the shape of the attention layer (n_outputs, n_attention)
Sourcepub const fn dim_input(&self) -> (usize, usize)
pub const fn dim_input(&self) -> (usize, usize)
the shape of the input layer (inputs, n_hidden)
the shape of the hidden layer (hidden, hidden)
Sourcepub const fn dim_memory(&self) -> (usize, usize)
pub const fn dim_memory(&self) -> (usize, usize)
the shape of the memory matrix (n_memory, n_attention)
Sourcepub const fn dim_output(&self) -> (usize, usize)
pub const fn dim_output(&self) -> (usize, usize)
the shape of the output layer (n_hidden, n_out)
Sourcepub fn set_attention(&mut self, attention: usize)
pub fn set_attention(&mut self, attention: usize)
set the number of features for attention
Sourcepub fn set_inputs(&mut self, inputs: usize)
pub fn set_inputs(&mut self, inputs: usize)
set the number of features for then input layer
set the number of features for the hidden layer
Sourcepub fn set_outputs(&mut self, outputs: usize)
pub fn set_outputs(&mut self, outputs: usize)
set the number of features for the output layer
Sourcepub fn with_attention(self, attention: usize) -> NeuralFeatures
pub fn with_attention(self, attention: usize) -> NeuralFeatures
consumes the current instance; returns another with the given number of features for attention
Sourcepub fn with_codex(self, codex: usize) -> NeuralFeatures
pub fn with_codex(self, codex: usize) -> NeuralFeatures
consumes the current instance; returns another with the given number of features for the read/write heads
Sourcepub fn with_inputs(self, inputs: usize) -> NeuralFeatures
pub fn with_inputs(self, inputs: usize) -> NeuralFeatures
consumes the current instance; returns another with the given number of input features
consumes the current instance; returns another with the given number of hidden features
Sourcepub fn with_outputs(self, outputs: usize) -> NeuralFeatures
pub fn with_outputs(self, outputs: usize) -> NeuralFeatures
consumes the current instance; returns another with the given number of output features